==> speech-analytic-testing_0.11.0_database.tar.gz: database/mssql/tables/AuditorEvaluationPlan.sql <==
CREATE TABLE [dbo].[AuditorEvaluationPlan] (
   [Instance] [varchar](50) NOT NULL ,
   [IdEvaluationPlan] [varchar](50) NOT NULL ,
   [IdAuditor] [varchar](50) NOT NULL ,
   [IdInteraction] [varchar](250) NOT NULL ,
   [TimeStamp] [datetime] NULL   ,
   [Completed] [bit] NULL   ,
   [Score] [numeric](5,2) NULL  ,
   [AutomaticScore] [numeric](5,2) NULL  ,
   [ManualScore] [numeric](5,2) NULL  ,
   [LastModifiedByUserId] [varchar](50) NULL ,
   [LastModifiedDate] [datetime] NULL   ,
   [IdCampaign] [varchar](50) NOT NULL ,
   [IdAgent] [varchar](50) NOT NULL ,
   [InteractionDate] [datetime] NULL   ,
   [InteractionType] [varchar](50) NOT NULL ,
   [InteractionDuration] [numeric](8,0) NULL  ,
   [InteractionOrigin] [varchar](50) NULL ,
   [InteractionFormat] [varchar](50) NULL ,
   [InteractionDateEnd] [datetime] NULL   ,
   [ManagementResult] [varchar](50) NULL ,
   [ContactId] [varchar](50) NULL 

   ,CONSTRAINT [PK_AuditorEvaluationPlan_1] PRIMARY KEY CLUSTERED ([Instance], [IdEvaluationPlan], [IdAuditor], [IdInteraction], [IdAgent], [InteractionType])
)

CREATE  NONCLUSTERED INDEX [IX_AuditorEvaluationPlan] ON [dbo].[AuditorEvaluationPlan] ([Instance], [IdAuditor], [IdCampaign], [IdAgent], [InteractionType], [InteractionOrigin], [InteractionFormat], [ManagementResult])
CREATE  NONCLUSTERED INDEX [IX_AuditorEvaluationPlan_IdEvaluationPlan] ON [dbo].[AuditorEvaluationPlan] ([IdEvaluationPlan]) INCLUDE ([Instance], [IdAuditor], [IdInteraction], [IdAgent], [InteractionType])

GO

==> speech-analytic-testing_0.16.1_database.tar.gz: database/mssql/tables/AuditorEvaluationPlan.sql <==
CREATE TABLE [dbo].[AuditorEvaluationPlan] (
   [Instance] [varchar](50) NOT NULL ,
   [IdEvaluationPlan] [varchar](50) NOT NULL ,
   [IdAuditor] [varchar](50) NOT NULL ,
   [IdInteraction] [varchar](250) NOT NULL ,
   [Completed] [bit] NULL   ,
   [Score] [numeric](5,2) NULL  ,
   [AutomaticScore] [numeric](5,2) NULL  ,
   [ManualScore] [numeric](5,2) NULL  ,
   [IdCampaign] [varchar](50) NOT NULL ,
   [IdAgent] [varchar](50) NOT NULL ,
   [InteractionDate] [datetime] NULL   ,
   [InteractionType] [varchar](50) NOT NULL ,
   [InteractionDuration] [numeric](8,0) NULL  ,
   [InteractionOrigin] [varchar](50) NULL ,
   [InteractionFormat] [varchar](50) NULL ,
   [InteractionDateEnd] [datetime] NULL   ,
   [ManagementResult] [varchar](50) NULL ,
   [ContactId] [varchar](50) NULL ,
   [Status] [bit] NULL 
      CONSTRAINT [DF_AuditorEvaluationPlan_IsDeleted] DEFAULT ((1))  ,
   [CreatedByUserId] [varchar](50) NULL ,
   [CreatedDate] [datetime] NULL   ,
   [LastModifiedByUserId] [varchar](50) NULL ,
   [LastModifiedDate] [datetime] NULL   ,
   [TimeStamp] [datetime] NULL   

   ,CONSTRAINT [PK_AuditorEvaluationPlan_1] PRIMARY KEY CLUSTERED ([Instance], [IdEvaluationPlan], [IdAuditor], [IdInteraction], [IdAgent], [InteractionType])
)

CREATE  NONCLUSTERED INDEX [IX_AuditorEvaluationPlan] ON [dbo].[AuditorEvaluationPlan] ([Instance], [IdAuditor], [IdCampaign], [IdAgent], [InteractionType], [InteractionOrigin], [InteractionFormat], [ManagementResult])
CREATE  NONCLUSTERED INDEX [IX_AuditorEvaluationPlan_IdEvaluationPlan] ON [dbo].[AuditorEvaluationPlan] ([IdEvaluationPlan]) INCLUDE ([Instance], [IdAuditor], [IdInteraction], [IdAgent], [InteractionType])

GO
